# Generated by Django 3.2.20 on 2023-08-31 14:31

from django.db import migrations
import wagtail.blocks
import wagtail.fields
import wagtail.images.blocks


class Migration(migrations.Migration):
    dependencies = [
        ("coyote", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="coyotehomepage",
            name="content",
            field=wagtail.fields.StreamField(
                [
                    (
                        "Afbeelding_met_tekst",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="image",
                        ),
                    ),
                    (
                        "Iconen_met_tekst",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="info-circle",
                        ),
                    ),
                    (
                        "Center_tekts",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="collapse-down",
                        ),
                    ),
                    (
                        "Logos",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="tag",
                        ),
                    ),
                    (
                        "Quotes",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="openquote",
                        ),
                    ),
                    (
                        "Jumbotron",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="form",
                        ),
                    ),
                    (
                        "Accordeon",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="list-ul",
                        ),
                    ),
                    (
                        "Producten",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="tag",
                        ),
                    ),
                    (
                        "Categorieen",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="clipboard-list",
                        ),
                    ),
                ],
                blank=True,
                verbose_name="Inhoud",
            ),
        ),
        migrations.AddField(
            model_name="coyotehomepage",
            name="footer",
            field=wagtail.fields.StreamField(
                [
                    (
                        "Call_To_Action",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="chain-broken",
                        ),
                    ),
                    (
                        "Nieuwsbrief",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="mail",
                        ),
                    ),
                ],
                blank=True,
                verbose_name="Footer",
            ),
        ),
        migrations.AddField(
            model_name="coyotehomepage",
            name="header",
            field=wagtail.fields.StreamField(
                [
                    (
                        "Fotos",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ]
                        ),
                    ),
                    (
                        "Video",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "video",
                                    wagtail.blocks.CharBlock(
                                        label="Video", required=False
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                            ]
                        ),
                    ),
                    (
                        "Content",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("left", "Links"),
                                            ("right", "Rechts"),
                                        ],
                                        label="Postion of the image",
                                        required=False,
                                    ),
                                ),
                            ]
                        ),
                    ),
                ],
                blank=True,
                verbose_name="Header",
            ),
        ),
    ]



# Generated by Django 5.2.3 on 2025-09-29 14:06

import django.db.models.deletion
from django.db import migrations, models, connection


def drop_page_ptr(apps, schema_editor):
    """
    We have to do some stupid workaround for deleting the page_ptr_id for sqlite.

    Somehow the normal migration does not do what we want and page_ptr_id is not removed from the table for sqlite.

    Hence we do the following manually, which does work!

    1. Creating a new temporary table without the unwanted column.
    2. Copying all existing data over.
    3. Dropping the old table.
    4. Renaming the new table.


    For postgres we do the normal operation, but we do it in the RunPython method because it's conditional.
    """

    if connection.vendor == "sqlite":
        with connection.cursor() as cursor:
            cursor.execute("PRAGMA foreign_keys=off;")

            cursor.execute("""
                CREATE TABLE new_coyote_coyotehomepage (
                    abstractbasepage_ptr_id integer NOT NULL PRIMARY KEY 
                        REFERENCES "ocyan_plugin_wagtail_abstractbasepage" ("page_ptr_id") DEFERRABLE INITIALLY DEFERRED,
                    content text NOT NULL CHECK ((JSON_VALID("content") OR "content" IS NULL)),
                    footer text NOT NULL CHECK ((JSON_VALID("footer") OR "footer" IS NULL)),
                    header text NOT NULL CHECK ((JSON_VALID("header") OR "header" IS NULL))
                );
            """)
            cursor.execute("""
                INSERT INTO new_coyote_coyotehomepage (abstractbasepage_ptr_id, content, footer, header)
                SELECT abstractbasepage_ptr, content, footer, header FROM coyote_coyotehomepage;
            """)
            cursor.execute("DROP TABLE coyote_coyotehomepage;")
            cursor.execute(
                "ALTER TABLE new_coyote_coyotehomepage RENAME TO coyote_coyotehomepage;"
            )

            cursor.execute("""
                CREATE TABLE new_coyote_coyotecontactpage (
                    abstractbasepage_ptr_id integer NOT NULL PRIMARY KEY 
                        REFERENCES "ocyan_plugin_wagtail_abstractbasepage" ("page_ptr_id") DEFERRABLE INITIALLY DEFERRED,
                    header text NOT NULL CHECK ((JSON_VALID("header") OR "header" IS NULL)),
                    content text NOT NULL CHECK ((JSON_VALID("content") OR "content" IS NULL)),
                    footer text NOT NULL CHECK ((JSON_VALID("footer") OR "footer" IS NULL))
                );
            """)
            cursor.execute("""
                INSERT INTO new_coyote_coyotecontactpage (abstractbasepage_ptr_id, header, content, footer)
                SELECT abstractbasepage_ptr, header, content, footer FROM coyote_coyotecontactpage;
            """)
            cursor.execute("DROP TABLE coyote_coyotecontactpage;")
            cursor.execute(
                "ALTER TABLE new_coyote_coyotecontactpage RENAME TO coyote_coyotecontactpage;"
            )

            cursor.execute("PRAGMA foreign_keys=on;")
    else:
        CoyoteContactPage = apps.get_model("coyote", "CoyoteContactPage")
        CoyoteHomePage = apps.get_model("coyote", "CoyoteHomePage")

        schema_editor.remove_field(
            CoyoteContactPage, CoyoteContactPage._meta.get_field("page_ptr")
        )
        schema_editor.remove_field(
            CoyoteContactPage, CoyoteContactPage._meta.get_field("search_image")
        )
        schema_editor.remove_field(
            CoyoteHomePage, CoyoteHomePage._meta.get_field("page_ptr")
        )
        schema_editor.remove_field(
            CoyoteHomePage, CoyoteHomePage._meta.get_field("search_image")
        )

        new_homepagefield = models.OneToOneField(
            "ocyan_plugin_wagtail.AbstractBasePage",
            on_delete=django.db.models.deletion.CASCADE,
            auto_created=True,
            parent_link=True,
            primary_key=True,
            serialize=False,
        )

        new_homepagefield.set_attributes_from_name("abstractbasepage_ptr")
        new_homepagefield.model = CoyoteContactPage
        new_homepagefield.contribute_to_class(CoyoteContactPage, "abstractbasepage_ptr")

        new_contactfield = models.OneToOneField(
            "ocyan_plugin_wagtail.AbstractBasePage",
            on_delete=django.db.models.deletion.CASCADE,
            auto_created=True,
            parent_link=True,
            primary_key=True,
            serialize=False,
        )

        new_contactfield.set_attributes_from_name("abstractbasepage_ptr")
        new_contactfield.model = CoyoteHomePage
        new_contactfield.contribute_to_class(CoyoteHomePage, "abstractbasepage_ptr")

        schema_editor.alter_field(
            CoyoteContactPage,
            CoyoteContactPage._meta.get_field("abstractbasepage_ptr"),
            new_contactfield,
            strict=True,
        )
        schema_editor.alter_field(
            CoyoteHomePage,
            CoyoteHomePage._meta.get_field("abstractbasepage_ptr"),
            new_homepagefield,
            strict=True,
        )


class Migration(migrations.Migration):
    dependencies = [
        ("coyote", "0023_auto_20250929_1604"),
        ("ocyan_plugin_wagtail", "0029_alter_abstractbasepage_canonical_url"),
    ]

    operations = [
        migrations.RunPython(drop_page_ptr, migrations.RunPython.noop),
    ]



# -*- coding: utf-8 -*-
import os

from ocyan.core.plugins import OcyanPluginConfig
from ocyan.core.utils import merge_dicts


class CoyoteConfig(OcyanPluginConfig):
    def contribute_to_installed_apps(self, installed_apps):
        installed_apps.wagtail.append("ocyan.plugin.coyote")
        installed_apps.front.register_extension(
            "ocyan.plugin.coyote.theme_extension", "oxyan.themes"
        )
        installed_apps.front.register_extension(
            "ocyan.plugin.coyote.theme_extension", "ocyan.plugin.barebone"
        )
        return installed_apps

    def contribute_to_settings(self, settings):
        SETTINGS = {
            "COMPRESS_CACHE_KEY_FUNCTION": "ocyan.plugin.coyote.utils.get_compressor_cache_key",
            "OXYAN_LAZY_THEME_DEFINITIONS": "ocyan.plugin.coyote.definitions.get_coyote_definitions",
        }
        if google_fonts_api_key := os.environ.get("GOOGLE_FONTS_API_KEY"):
            SETTINGS["GOOGLE_FONTS_API_KEY"] = google_fonts_api_key

        DEFAULTS = {
            "OXYAN_HEADER_OPTIONS": [],
        }

        # Merge settings with override, and add defaults without override
        return merge_dicts(
            merge_dicts(settings, SETTINGS, overwrite=True),
            DEFAULTS,
            overwrite=False,
        )



# Generated by Django 5.2.3 on 2025-10-01 09:31

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("coyote", "0024_remove_coyotecontactpage_page_ptr_and_more"),
        ("ocyan_plugin_wagtail", "0029_alter_abstractbasepage_canonical_url"),
    ]

    operations = [
        migrations.SeparateDatabaseAndState(
            database_operations=[],
            state_operations=[
                migrations.RemoveField(
                    model_name="coyotecontactpage",
                    name="page_ptr",
                ),
                migrations.RemoveField(
                    model_name="coyotecontactpage",
                    name="search_image",
                ),
                migrations.RemoveField(
                    model_name="coyotehomepage",
                    name="page_ptr",
                ),
                migrations.RemoveField(
                    model_name="coyotehomepage",
                    name="search_image",
                ),
                migrations.AlterField(
                    model_name="coyotecontactpage",
                    name="abstractbasepage_ptr",
                    field=models.OneToOneField(
                        auto_created=True,
                        default=None,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="ocyan_plugin_wagtail.abstractbasepage",
                    ),
                    preserve_default=False,
                ),
                migrations.AlterField(
                    model_name="coyotehomepage",
                    name="abstractbasepage_ptr",
                    field=models.OneToOneField(
                        auto_created=True,
                        default=None,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="ocyan_plugin_wagtail.abstractbasepage",
                    ),
                    preserve_default=False,
                ),
            ],
        )
    ]



# Generated by Django 5.2.3 on 2026-06-30 23:07

import ocyan.plugin.coyote.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0025_remove_coyotecontactpage_page_ptr_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="coyotecontactpage",
            name="content",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, verbose_name="Content"
            ),
        ),
        migrations.AlterField(
            model_name="coyotehomepage",
            name="content",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, verbose_name="Content"
            ),
        ),
    ]



import json
import os
import tempfile
import time
from unittest import mock

from django.test import SimpleTestCase

from ocyan.plugin.coyote import utils


class DummyResponse:
    def __init__(self, payload):
        self._payload = payload

    def raise_for_status(self):
        return None

    def json(self):
        return self._payload


class GetGoogleFontsTests(SimpleTestCase):
    def setUp(self):
        super().setUp()
        self.tmpdir = tempfile.TemporaryDirectory()
        self.cache_path = os.path.join(self.tmpdir.name, "google-fonts.json")

    def tearDown(self):
        self.tmpdir.cleanup()
        super().tearDown()

    def _write_cache(self, payload, age_seconds):
        with open(self.cache_path, "w", encoding="utf-8") as handle:
            json.dump(payload, handle)
        stale_time = time.time() - age_seconds
        os.utime(self.cache_path, (stale_time, stale_time))

    def test_uses_fresh_cache_without_network(self):
        payload = [{"family": "Inter"}]
        self._write_cache(payload, age_seconds=30)

        with self.settings(
            COYOTE_GOOGLE_FONTS_CACHE_PATH=self.cache_path,
            COYOTE_GOOGLE_FONTS_CACHE_TTL_SECONDS=300,
            GOOGLE_FONTS_API_KEY="dummy",
        ):
            with mock.patch("ocyan.plugin.coyote.utils.requests.get") as mocked_get:
                result = utils.get_google_fonts()

        self.assertEqual(result, payload)
        mocked_get.assert_not_called()

    def test_refreshes_expired_cache_from_api(self):
        self._write_cache([{"family": "Old"}], age_seconds=3600)
        api_payload = [{"family": "Roboto"}]

        with self.settings(
            COYOTE_GOOGLE_FONTS_CACHE_PATH=self.cache_path,
            COYOTE_GOOGLE_FONTS_CACHE_TTL_SECONDS=10,
            GOOGLE_FONTS_API_KEY="dummy",
        ):
            with mock.patch(
                "ocyan.plugin.coyote.utils.requests.get",
                return_value=DummyResponse({"items": api_payload}),
            ) as mocked_get:
                result = utils.get_google_fonts()

        self.assertEqual(result, api_payload)
        mocked_get.assert_called_once()
        with open(self.cache_path, "r", encoding="utf-8") as handle:
            self.assertEqual(json.load(handle), api_payload)

    def test_uses_stale_cache_when_api_fails(self):
        stale_payload = [{"family": "Fallback"}]
        self._write_cache(stale_payload, age_seconds=7200)

        with self.settings(
            COYOTE_GOOGLE_FONTS_CACHE_PATH=self.cache_path,
            COYOTE_GOOGLE_FONTS_CACHE_TTL_SECONDS=30,
            GOOGLE_FONTS_API_KEY="dummy",
        ):
            with mock.patch(
                "ocyan.plugin.coyote.utils.requests.get",
                side_effect=utils.requests.RequestException("boom"),
            ):
                result = utils.get_google_fonts()

        self.assertEqual(result, stale_payload)

    def test_returns_empty_when_api_key_is_missing(self):
        with self.settings(
            COYOTE_GOOGLE_FONTS_CACHE_PATH=self.cache_path,
            COYOTE_GOOGLE_FONTS_CACHE_TTL_SECONDS=30,
            GOOGLE_FONTS_API_KEY="",
        ):
            with mock.patch("ocyan.plugin.coyote.utils.requests.get") as mocked_get:
                result = utils.get_google_fonts()

        self.assertEqual(result, [])
        mocked_get.assert_not_called()



from wagtail import blocks

from .content import (
    BootstrapTabBlock,
    CounterAttribute,
    CoyoteAccordionAllBlock,
    CoyoteAccordionBlock,
    CoyoteCenterText,
    CoyoteIconBlock,
    CoyoteIconsWithText,
    CoyoteImageWithText,
    CoyoteLogos,
    CoyotePersonBlock,
    CoyotePersonListBlock,
    CoyoteQuoteBlock,
    CoyoteQuotesBlock,
    CoyoteTabsBlock,
    CoyoteTextListBlock,
)
from .footer import CoyoteCallToAction
from .header import (
    CoyoteCHeaderImages,
    CoyoteContent,
    CoyoteImages,
    CoyoteVideo,
)


class CoyoteDummyBlock(blocks.StaticBlock):
    pass


__all__ = [
    "BootstrapTabBlock",
    "CounterAttribute",
    "CoyoteAccordionAllBlock",
    "CoyoteAccordionBlock",
    "CoyoteCHeaderImages",
    "CoyoteCallToAction",
    "CoyoteCenterText",
    "CoyoteContent",
    "CoyoteDummyBlock",
    "CoyoteIconBlock",
    "CoyoteIconsWithText",
    "CoyoteImageWithText",
    "CoyoteImages",
    "CoyoteLogos",
    "CoyotePersonBlock",
    "CoyotePersonListBlock",
    "CoyoteQuoteBlock",
    "CoyoteQuotesBlock",
    "CoyoteTabsBlock",
    "CoyoteTextListBlock",
    "CoyoteVideo",
]



from django.utils.translation import gettext_lazy as _

from wagtail.blocks import StreamBlock

from ocyan.main.loading import get_ocyan_classes

# pylint: disable=unbalanced-tuple-unpacking
(
    CoyoteImages,
    CoyoteVideo,
    CoyoteContent,
    CoyoteIconsWithText,
    CoyoteLogos,
    CoyoteCallToAction,
    CoyoteCenterText,
    CoyoteTabsBlock,
    CoyoteImageWithText,
    CoyoteCHeaderImages,
    CoyoteAccordionAllBlock,
    CoyoteDummyBlock,
    CoyotePersonListBlock,
    CoyoteQuotesBlock,
    CoyoteTextListBlock,
) = get_ocyan_classes(
    "coyote.blocks",
    [
        "CoyoteImages",
        "CoyoteVideo",
        "CoyoteContent",
        "CoyoteIconsWithText",
        "CoyoteLogos",
        "CoyoteCallToAction",
        "CoyoteCenterText",
        "CoyoteTabsBlock",
        "CoyoteImageWithText",
        "CoyoteCHeaderImages",
        "CoyoteAccordionAllBlock",
        "CoyoteDummyBlock",
        "CoyotePersonListBlock",
        "CoyoteQuotesBlock",
        "CoyoteTextListBlock",
    ],
)


class HomePageHeaderStreamBlock(StreamBlock):
    picture = CoyoteImages()
    video = CoyoteVideo()
    content = CoyoteContent()


class HomePageContentStreamBlock(StreamBlock):
    picture_with_text = CoyoteImageWithText(icon="image", label=_("Image with text"))
    icons_with_text = CoyoteIconsWithText(
        icon="info-circle", label=_("Icons with text")
    )
    centered_content = CoyoteCenterText(
        icon="collapse-down", label=_("Centered content")
    )
    logos = CoyoteLogos(icon="tag", label=_("Logos"))
    quotes = CoyoteQuotesBlock(icon="openquote", label=_("Quotes"))
    accordion = CoyoteAccordionAllBlock(icon="list-ul", label=_("Accordion"))
    tabbed_content = CoyoteTabsBlock(icon="list-ul", label=_("Tabbed content"))
    about_us = CoyotePersonListBlock(icon="group", label=_("About us"))
    paragraph_columns = CoyoteTextListBlock(
        icon="list-ul", label=_("Paragraph columns")
    )


class HomePageFooterStreamBlock(StreamBlock):
    call_to_action = CoyoteCallToAction(icon="chain-broken", label=_("Call to action"))
    newsletter = CoyoteDummyBlock(icon="mail", label=_("Newsletter"))


class ContactPageHeaderStreamBlock(StreamBlock):
    picture = CoyoteCHeaderImages()


class ContactPageContentStreamBlock(StreamBlock):
    centered_content = CoyoteCenterText(
        icon="collapse-down", label=_("Centered content")
    )
    logos = CoyoteLogos(icon="tag", label=_("Logos"))
    quotes = CoyoteQuotesBlock(icon="openquote", label=_("Quotes"))
    accordion = CoyoteAccordionAllBlock(icon="list-ul", label=_("Accordion"))
    tabbed_content = CoyoteTabsBlock(icon="list-ul", label=_("Tabbed content"))


class ContactPageFooterStreamBlock(StreamBlock):
    call_to_action = CoyoteCallToAction(icon="chain-broken", label=_("Call to action"))
    newsletter = CoyoteDummyBlock(icon="mail", label=_("Newsletter"))



# -*- coding: utf-8 -*-
default_app_config = "ocyan.plugin.coyote.apps.OcyanPluginCoyoteAppConfig"

__all__ = ["CoyoteConfig"]


def __getattr__(name):
    if name == "CoyoteConfig":
        from .entrypoint import CoyoteConfig

        return CoyoteConfig
    raise AttributeError(f"module {__name__!r} has no attribute {name!r}")



import json
import logging
import os
import tempfile
import time
from typing import Any, Dict, List, Optional

import requests
from django.conf import settings
from wagtail.models import Page

from ocyan.plugin.wagtail.localization import (
    localize_internal_path,
    resolve_page_for_language,
)
from ocyan.plugin.wagtail.middleware import get_current_request

logger = logging.getLogger(__name__)
DEFAULT_GOOGLE_FONTS_CACHE_PATH = "/tmp/google-fonts.json"
DEFAULT_GOOGLE_FONTS_CACHE_TTL_SECONDS = 60 * 60 * 24
DEFAULT_GOOGLE_FONTS_RETRY_COOLDOWN_SECONDS = 60 * 10
_google_fonts_state = {
    "next_retry_at": 0,
    "last_error_log_at": 0,
    "missing_key_logged": False,
}


def exclude_none_values(d: dict) -> dict:
    """
    Exclude items where value is None from dict

    >>> d = {'a': None, 'b': 'myname', 'c': 122}
    >>> exclude_none_values(d)
    {'b': 'myname', 'c': 122}
    """
    return {k: v for k, v in d.items() if v is not None}


def get_google_fonts():
    """
    Try to get the fonts from /tmp/google-fonts.json.
    If it doesn't exists get from google and save in /tmp/.
    """
    cache_path = getattr(
        settings, "COYOTE_GOOGLE_FONTS_CACHE_PATH", DEFAULT_GOOGLE_FONTS_CACHE_PATH
    )
    cache_ttl_seconds = _get_cache_ttl_seconds()
    retry_cooldown_seconds = _get_retry_cooldown_seconds()

    cached_fonts = _read_cached_fonts(cache_path, cache_ttl_seconds)
    if cached_fonts is not None:
        return cached_fonts
    now = int(time.time())
    if now < _google_fonts_state["next_retry_at"]:
        return _read_cached_fonts(cache_path, cache_ttl_seconds, allow_stale=True) or []

    api_key = getattr(settings, "GOOGLE_FONTS_API_KEY", None)
    if not api_key:
        if not _google_fonts_state["missing_key_logged"]:
            logger.warning("GOOGLE_FONTS_API_KEY is not configured.")
            _google_fonts_state["missing_key_logged"] = True
        return []

    google_fonts_url = f"https://www.googleapis.com/webfonts/v1/webfonts?key={api_key}"

    try:
        response = requests.get(google_fonts_url, timeout=(5, 30))
        response.raise_for_status()
        data = response.json()
        fonts = data.get("items", [])
        if not isinstance(fonts, list):
            logger.warning("Google Fonts API response missing 'items' list.")
            return (
                _read_cached_fonts(cache_path, cache_ttl_seconds, allow_stale=True)
                or []
            )

        _write_cached_fonts(cache_path, fonts)

        return fonts
    except (requests.RequestException, ValueError, OSError) as exc:
        now = int(time.time())
        if now >= _google_fonts_state["last_error_log_at"] + retry_cooldown_seconds:
            logger.warning("Unable to load Google Fonts: %s", exc)
            _google_fonts_state["last_error_log_at"] = now
        _google_fonts_state["next_retry_at"] = now + retry_cooldown_seconds
        return _read_cached_fonts(cache_path, cache_ttl_seconds, allow_stale=True) or []


def _get_cache_ttl_seconds() -> int:
    ttl = getattr(
        settings,
        "COYOTE_GOOGLE_FONTS_CACHE_TTL_SECONDS",
        DEFAULT_GOOGLE_FONTS_CACHE_TTL_SECONDS,
    )
    try:
        ttl_int = int(ttl)
    except (TypeError, ValueError):
        logger.warning(
            "Invalid COYOTE_GOOGLE_FONTS_CACHE_TTL_SECONDS=%r, using default %s.",
            ttl,
            DEFAULT_GOOGLE_FONTS_CACHE_TTL_SECONDS,
        )
        return DEFAULT_GOOGLE_FONTS_CACHE_TTL_SECONDS
    return max(ttl_int, 0)


def _get_retry_cooldown_seconds() -> int:
    retry_cooldown = getattr(
        settings,
        "COYOTE_GOOGLE_FONTS_RETRY_COOLDOWN_SECONDS",
        DEFAULT_GOOGLE_FONTS_RETRY_COOLDOWN_SECONDS,
    )
    try:
        retry_cooldown_int = int(retry_cooldown)
    except (TypeError, ValueError):
        logger.warning(
            "Invalid COYOTE_GOOGLE_FONTS_RETRY_COOLDOWN_SECONDS=%r, using default %s.",
            retry_cooldown,
            DEFAULT_GOOGLE_FONTS_RETRY_COOLDOWN_SECONDS,
        )
        return DEFAULT_GOOGLE_FONTS_RETRY_COOLDOWN_SECONDS
    return max(retry_cooldown_int, 0)


def _read_cached_fonts(
    cache_path: str, cache_ttl_seconds: int, allow_stale: bool = False
) -> Optional[List[Dict[str, Any]]]:
    try:
        with open(cache_path, "r", encoding="utf-8") as f:
            cached_fonts = json.load(f)
        if not isinstance(cached_fonts, list):
            return None
        if allow_stale:
            return cached_fonts

        cache_age = max(0, int(time.time() - os.path.getmtime(cache_path)))
        if cache_ttl_seconds == 0:
            return None
        if cache_age <= cache_ttl_seconds:
            return cached_fonts
        return None
    except FileNotFoundError:
        return None
    except (json.JSONDecodeError, OSError):
        logger.info("Resetting invalid Google Fonts cache %s.", cache_path)
        try:
            if os.path.exists(cache_path):
                os.remove(cache_path)
        except OSError:
            pass
        return None


def _write_cached_fonts(cache_path: str, fonts: List[Dict[str, Any]]) -> None:
    tmp_path = None
    cache_dir = os.path.dirname(cache_path) or "."
    os.makedirs(cache_dir, exist_ok=True)
    try:
        fd, tmp_path = tempfile.mkstemp(
            prefix=".google-fonts-", suffix=".json", dir=cache_dir
        )
        with os.fdopen(fd, "w", encoding="utf-8") as f:
            json.dump(fonts, f)
        os.replace(tmp_path, cache_path)
    finally:
        if tmp_path and os.path.exists(tmp_path):
            os.remove(tmp_path)


def get_compressor_cache_key(key):
    """
    compressor cache per domain
    """

    if request := get_current_request():
        return key + request.get_host()

    return key


class LinkPageString(str):
    def get_url(self):
        return localize_internal_path(self, request=get_current_request())


class LocalizedLinkPage:
    def __init__(self, page: Page):
        self.page = page

    @property
    def resolved_page(self):
        return resolve_page_for_language(self.page, request=get_current_request())

    def get_url(self):
        return self.resolved_page.get_url(request=get_current_request())

    @property
    def pk(self):
        return self.page.pk

    def __getattr__(self, item):
        return getattr(self.resolved_page, item)



COYOTE_COLOR_CHOICES = [
    ("primary", "Primary"),
    ("secondary", "Secondary"),
    ("light", "Light"),
    ("dark", "Dark"),
    ("outline-primary", "Primary border"),
    ("outline-secondary", "Secondary border"),
    ("outline-light", "Light border"),
    ("outline-dark", "Dark border"),
]



from django import forms


class LinkModelChoiceField(forms.ModelChoiceField):
    def to_python(self, value):
        if value is not None and value.isdigit():
            return super().to_python(value)

        return value



# -*- coding: utf-8 -*-
from pathlib import Path

from setuptools import find_packages, setup

install_requires: list = ["ocyan.core", "wagtail-roadrunner", "oxyan.themes"]

extras_require: dict = {
    "test": [
        "empty_testproject",
        "ocyan.plugin.testing",
        "pylint-django",
        "ruff",
        "vdt.versionplugin.wheel",
        "coverage",
    ]
}

PACKAGE_CLASSIFIERS = [
    "License :: Other/Proprietary License",
    "Framework :: Ocyan",
    "Environment :: Plugins",
]

setup(
    name="ocyan.plugin.coyote",
    version="0.3.1",
    url="https://git.mandelblog.com/mandel-plugins/ocyan.plugin.coyote",
    author="Mandel",
    author_email="info@mandelblog.com",
    description="Wagtail page, block, and styling plugin for Ocyan themes.",
    long_description=Path("README.md").read_text(encoding="utf-8"),
    long_description_content_type="text/markdown",
    packages=find_packages(),
    include_package_data=True,
    python_requires=">=3.6",
    install_requires=install_requires,
    classifiers=PACKAGE_CLASSIFIERS,
    extras_require=extras_require,
)



from wagtail import fields


class CoyoteStreamField(fields.StreamField):
    def deconstruct(self):
        name, path, _, kwargs = super().deconstruct()
        kwargs.pop("block_lookup")
        return (
            name,
            path,
            [
                (),
            ],
            kwargs,
        )

    def clone(self):
        """
        Uses super.deconstruct() to clone a new copy of this Field.
        Will not preserve any class attachments/attribute names.
        """
        _, __, args, kwargs = super().deconstruct()
        return self.__class__(*args, **kwargs)
